/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it
 * is applied to this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * AgroSense. If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.sensor.model;

import nl.cloudfarming.client.util.UOM;
import org.openide.util.NbBundle;

/**
 * Represents an Observation measurement type such as PH
 * Types can be translated via bundle messages 
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages({"NITROGEN_TOTAL=Nitrogen total",
                    "NITROGEN_DELIVERY_CAPACITY=Nitrogen delivery capacity",
                    "CARBON_NITROGEN_RATIO=Carbon nitrogen ratio",
                    "AVAILABLE_PHOSPHATE=Available phosphate",
                    "PHOSPHATE_SOIL_SUPPLY_PAL=Phosphate soil supply (PAL)",
                    "PHOSPHATE_SOIL_SUPPLY_PW=Phosphate soil supply (Pw)",
                    "AVAILABLE_POTASSIUM=Available Potassium (K-PAE)",
                    "POTASSIUM_SOIL_SUPPLY=Potassium soil supply (K-CEC)",
                    "SULFUR_TOTAL=Sulfur total",
                    "SULFUR_DELIVERY_CAPACITY=Sulfur delivery capacity",
                    "SULFUR_DELIVERY=Sulfur delivery(including delivery capacity)",
                    "AVAILABLE_MAGNESIUM=Available magnesium",
                    "AVAILABLE_SODIUM=Available sodium",
                    "ACIDITY=Acidity (PH)",
                    "ORGANIC_MATTER=Organic matter",
                    "CLAY=Clay",
                    "CALCAREOUS_LIME=Calcareous lime",
                    "CLAY_HUMUS=Clay-humus (CEC)",
                    "CALCIUM_OCCUPATION=Calcium occupation",
                    "SODIUM_OCCUPATION=Sodium occupation",
                    "POTASSIUM_OCCUPATION=Potassium occupation",
                    "SOIL_LIFE=Soil life",
                    "BODENPUNKTE=Bodenpunkte"})
public enum MeasurementType {
    NITROGEN_TOTAL("NITROGEN_TOTAL", UOM.MG_PER_KG),
    NITROGEN_DELIVERY_CAPACITY("NITROGEN_DELIVERY_CAPACITY", UOM.KG_PER_HA),
    //TODO: UOM is nitrogen carbon ratio does this need a UOM?
    CARBON_NITROGEN_RATIO("CARBON_NITROGEN_RATIO", UOM.NOT_SPECIFIED),
    AVAILABLE_PHOSPHATE("AVAILABLE_PHOSPHATE", UOM.MG_PER_KG),
    PHOSPHATE_SOIL_SUPPLY_PAL("PHOSPHATE_SOIL_SUPPLY_PAL", UOM.MG_PER_100G),
    PHOSPHATE_SOIL_SUPPLY_PW("PHOSPHATE_SOIL_SUPPLY_PW", UOM.MG_PER_L),
    AVAILABLE_POTASSIUM("AVAILABLE_POTASSIUM", UOM.MG_PER_KG),
    //TODO: does this need an UOM?
    POTASSIUM_SOIL_SUPPLY("POTASSIUM_SOIL_SUPPLY", UOM.NOT_SPECIFIED),
    SULFUR_TOTAL("SULFUR_TOTAL", UOM.MG_PER_KG),
    SULFUR_DELIVERY_CAPACITY("SULFUR_DELIVERY_CAPACITY", UOM.KG_PER_HA),
    SULFUR_DELIVERY("SULFUR_DELIVERY", UOM.KG_PER_HA),
    AVAILABLE_MAGNESIUM("AVAILABLE_MAGNESIUM", UOM.MG_PER_KG),
    AVAILABLE_SODIUM("AVAILABLE_SODIUM", UOM.MG_PER_KG),
    ACIDITY("ACIDITY", UOM.PH),
    ORGANIC_MATTER("ORGANIC_MATTER", UOM.SOIL_PERCENTAGE),
    CLAY("CLAY", UOM.SOIL_PERCENTAGE),
    CALCAREOUS_LIME("CALCAREOUS_LIME", UOM.SOIL_PERCENTAGE),
    CLAY_HUMUS("CLAY_HUMUS", UOM.MMOL_PER_KG),
    CALCIUM_OCCUPATION("CALCIUM_OCCUPATION", UOM.CEC_PERCENTAGE),
    SODIUM_OCCUPATION("SODIUM_OCCUPATION", UOM.CEC_PERCENTAGE),
    POTASSIUM_OCCUPATION("POTASSIUM_OCCUPATION", UOM.CEC_PERCENTAGE),
    SOIL_LIFE("SOIL_LIFE", UOM.MG_PER_KG),
    BODENPUNKTE("BODENPUNKTE", UOM.BODENPUNKTE)
    ;
    private String bundleKey;
    private UOM unitOfMeasure;
    
    private MeasurementType(String bundleKey, UOM unitOfMeasure) {
        this.bundleKey = bundleKey;
        this.unitOfMeasure = unitOfMeasure;
    }

    /**
     * Get the {@link UOM} for this MeasurementType
     * @return 
     */
    public UOM getUnitOfMeasure() {
        return unitOfMeasure;
    }
    
    /**
     * Get's the returned string from the bundle
     * @return 
     */
    @Override
    public String toString(){
        return NbBundle.getMessage(getClass(), bundleKey);
    }
    
}
