/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify it under
 * the terms of the GNU General Public License as published by the Free Software
 * Foundation, either version 3 of the License, or (at your option) any later
 * version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it
 * is applied to this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful, but WITHOUT ANY
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * AgroSense. If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.sensor.model;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;
import java.io.IOException;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import nl.cloudfarming.client.model.AbstractEntityManager;
import nl.cloudfarming.client.model.AgroURI;
import org.netbeans.api.project.Project;
import org.openide.filesystems.FileObject;

/**
 * Abstract observation manager class 
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
public abstract class ObservationManager extends AbstractEntityManager<Observation>{
    
    public static final String OBSERVATIONS_DIR = "Observations";
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.sensor.model.ObservationManager");
    public static final String PROP_OBSERVATION = "observation";
    private final PropertyChangeSupport propertyChangeSupport = new PropertyChangeSupport(this);
    
    /**
     * Loads an observation for a specified {@link FileObject}
     * @param observationObject
     * @return 
     */
    public abstract Observation load(FileObject observationObject);
    
    /**
     * Get the Observations root Folder
     *
     * @param project the project to find the folder in
     * @param create if the folder should be created if not found
     * @return FileObject if found else null
     */
    public static FileObject getObservationsFolder(final Project project, boolean create) {
        //Get the stock directory, creating if deleted
        FileObject farmFolder = project.getProjectDirectory();
        FileObject observationsFolder = farmFolder.getFileObject(OBSERVATIONS_DIR);

        // Create field folder if it doesn't exist
        if (observationsFolder == null && create) {
            try {
                observationsFolder = farmFolder.createFolder(OBSERVATIONS_DIR);
            } catch (IOException ex) {
                LOGGER.log(Level.SEVERE, "Could not create the folder {0} in folder {1}", new Object[]{OBSERVATIONS_DIR, farmFolder.getPath()});
            }
        }
        return observationsFolder;
    }
    
    protected PropertyChangeSupport getPropertyChangeSupport(){
        return propertyChangeSupport;
    }
    
    public void addPropertyChangeListener(PropertyChangeListener changeListener){
        getPropertyChangeSupport().addPropertyChangeListener(changeListener);
    }
    
    public void addPropertyChangeListener(String prop, PropertyChangeListener changeListener){
        getPropertyChangeSupport().addPropertyChangeListener(prop, changeListener);
    }
    
    public void removePropertyChangeListener(PropertyChangeListener changeListener){
        getPropertyChangeSupport().removePropertyChangeListener(changeListener);
    }
    
    public void removePropertyChangeListener(String prop, PropertyChangeListener changeListener){
        getPropertyChangeSupport().removePropertyChangeListener(prop, changeListener);
    }
    
    /**
     * Get all the {@link Observation}'s for a source
     */
    public abstract List<FileObject> getObservationFileObjectsForSource(AgroURI source);
    
}
