/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.sensor.model;

import java.io.Serializable;
import java.util.Date;

/**
 * abstract base class for sensor data
 *
 * @author Merijn Zengers
 */
public class SensorObservation implements Serializable {

    private SensorRun sensorRun;
    /**
     * X
     */
//    @Index
    private double longitude;
    /**
     * Y
     */
//    @Index
    private double latitude;
    private Double ndvi;
    private Double wdvi;
    private Double reading1;
    private Double reading2;
    private Double reading3;
    private Date utcTime;
    private Double speed;
    private Double course;

   protected SensorObservation() {
    }

    public SensorObservation(double longitude, double latitude) {
        this.latitude = latitude;
        this.longitude = longitude;
    }

    public Double getNdvi() {
        return ndvi;
    }

    public void setNdvi(Double ndvi) {
        this.ndvi = ndvi;
    }

    public Double getWdvi() {
        return wdvi;
    }

    public void setWdvi(Double wdvi) {
        this.wdvi = wdvi;
    }

    public Double getCourse() {
        return course;
    }

    public void setCourse(Double course) {
        this.course = course;
    }


    public double getLatitude() {
        return latitude;
    }

    public void setLatitude(double latitude) {
        this.latitude = latitude;
    }

    public double getLongitude() {
        return longitude;
    }

    public void setLongitude(double longitude) {
        this.longitude = longitude;
    }

    public Double getReading1() {
        return reading1;
    }

    public void setReading1(Double reading1) {
        this.reading1 = reading1;
    }

    public Double getReading2() {
        return reading2;
    }

    public void setReading2(Double reading2) {
        this.reading2 = reading2;
    }

    public Double getReading3() {
        return reading3;
    }

    public void setReading3(Double reading3) {
        this.reading3 = reading3;
    }

    public SensorRun getSensorRun() {
        return sensorRun;
    }

    public void setSensorRun(SensorRun sensorRun) {
        this.sensorRun = sensorRun;
    }

    public Double getSpeed() {
        return speed;
    }

    public void setSpeed(Double speed) {
        this.speed = speed;
    }

    public Date getUtcTime() {
        return utcTime;
    }

    public void setUtcTime(Date utcTime) {
        this.utcTime = utcTime;
    }

    @Override
    public boolean equals(Object obj) {
        if (!super.equals(obj)) {
            return false;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final SensorObservation other = (SensorObservation) obj;
        if (this.sensorRun != other.sensorRun && (this.sensorRun == null || !this.sensorRun.equals(other.sensorRun))) {
            return false;
        }
        if (Double.doubleToLongBits(this.longitude) != Double.doubleToLongBits(other.longitude)) {
            return false;
        }
        if (Double.doubleToLongBits(this.latitude) != Double.doubleToLongBits(other.latitude)) {
            return false;
        }
        if (this.ndvi != other.ndvi && (this.ndvi == null || !this.ndvi.equals(other.ndvi))) {
            return false;
        }
        if (this.wdvi != other.wdvi && (this.wdvi == null || !this.wdvi.equals(other.wdvi))) {
            return false;
        }
        if (this.reading1 != other.reading1 && (this.reading1 == null || !this.reading1.equals(other.reading1))) {
            return false;
        }
        if (this.reading2 != other.reading2 && (this.reading2 == null || !this.reading2.equals(other.reading2))) {
            return false;
        }
        if (this.reading3 != other.reading3 && (this.reading3 == null || !this.reading3.equals(other.reading3))) {
            return false;
        }
        if (this.utcTime != other.utcTime && (this.utcTime == null || !this.utcTime.equals(other.utcTime))) {
            return false;
        }
        if (this.speed != other.speed && (this.speed == null || !this.speed.equals(other.speed))) {
            return false;
        }
        if (this.course != other.course && (this.course == null || !this.course.equals(other.course))) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = super.hashCode();
        hash = 13 * hash + (this.sensorRun != null ? this.sensorRun.hashCode() : 0);
        hash = 13 * hash + (int) (Double.doubleToLongBits(this.longitude) ^ (Double.doubleToLongBits(this.longitude) >>> 32));
        hash = 13 * hash + (int) (Double.doubleToLongBits(this.latitude) ^ (Double.doubleToLongBits(this.latitude) >>> 32));
        hash = 13 * hash + (this.ndvi != null ? this.ndvi.hashCode() : 0);
        hash = 13 * hash + (this.wdvi != null ? this.wdvi.hashCode() : 0);
        hash = 13 * hash + (this.reading1 != null ? this.reading1.hashCode() : 0);
        hash = 13 * hash + (this.reading2 != null ? this.reading2.hashCode() : 0);
        hash = 13 * hash + (this.reading3 != null ? this.reading3.hashCode() : 0);
        hash = 13 * hash + (this.utcTime != null ? this.utcTime.hashCode() : 0);
        hash = 13 * hash + (this.speed != null ? this.speed.hashCode() : 0);
        hash = 13 * hash + (this.course != null ? this.course.hashCode() : 0);
        return hash;
    }
}
