/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.sensor.model;

import java.io.Serializable;
import java.util.HashSet;
import java.util.Set;
import nl.cloudfarming.client.field.model.Field;
import nl.cloudfarming.client.model.AbstractEntity;
import nl.cloudfarming.client.model.EnterpriseIdProvider;
import nl.cloudfarming.client.model.ItemIdType;


/**
 * @author I. de Vries
 */
public class SensorRun extends AbstractEntity implements Serializable {
    
    
    public static final ItemIdType ITEM_ID_TYPE = ItemIdType.SRU;
    private Field field;
    
    private Set<SensorObservation> sensorData = new HashSet<SensorObservation>();
    
    private Double averageNdvi;
    private Double averageWdvi;   
   
    protected SensorRun(EnterpriseIdProvider eip) {
        super(eip, ITEM_ID_TYPE);
    }

    public Set<nl.cloudfarming.client.sensor.model.SensorObservation> getSensorData() {
        return sensorData;
    }

    public Field getField() {
        return field;
    }

    public void setField(Field field) {
        this.field = field;
    }
        
    public Double getAverageNdvi() {
        return averageNdvi;
    }

    public void setAverageNdvi(Double averageNdvi) {
        this.averageNdvi = averageNdvi;
    }

    public Double getAverageWdvi() {
        return averageWdvi;
    }

    public void setAverageWdvi(Double averageWdvi) {
        this.averageWdvi = averageWdvi;
    }

    @Override
    public boolean equals(Object obj) {
        if(!super.equals(obj)){
            return false;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final SensorRun other = (SensorRun) obj;

        if (this.field != other.field && (this.field == null || !this.field.equals(other.field))) {
            return false;
        }
        if (this.averageNdvi != other.averageNdvi && (this.averageNdvi == null || !this.averageNdvi.equals(other.averageNdvi))) {
            return false;
        }
        if (this.averageWdvi != other.averageWdvi && (this.averageWdvi == null || !this.averageWdvi.equals(other.averageWdvi))) {
            return false;
        }
        return true;
    }

    @Override
    public int hashCode() {
        int hash = super.hashCode();
        hash = 31 * hash + (this.field != null ? this.field.hashCode() : 0);
        hash = 31 * hash + (this.averageNdvi != null ? this.averageNdvi.hashCode() : 0);
        hash = 31 * hash + (this.averageWdvi != null ? this.averageWdvi.hashCode() : 0);
        return hash;
    }

    
    
    
}
